@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 # A library that provides a Python interface to the Telegram Bot API
-# Copyright (C) 2015-2022
+# Copyright (C) 2015-2023
 # Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 # This program is free software: you can redistribute it and/or modify
@@ -50,12 +50,17 @@ class ProximityAlertTriggered(TelegramObject):
     __slots__ = ("traveler", "distance", "watcher")
 
     def __init__(
-        self, traveler: User, watcher: User, distance: int, *, api_kwargs: JSONDict = None
+        self,
+        traveler: User,
+        watcher: User,
+        distance: int,
+        *,
+        api_kwargs: Optional[JSONDict] = None,
     ):
         super().__init__(api_kwargs=api_kwargs)
-        self.traveler = traveler
-        self.watcher = watcher
-        self.distance = distance
+        self.traveler: User = traveler
+        self.watcher: User = watcher
+        self.distance: int = distance
 
         self._id_attrs = (self.traveler, self.watcher, self.distance)
 
