@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 #
 #  A library that provides a Python interface to the Telegram Bot API
-#  Copyright (C) 2015-2022
+#  Copyright (C) 2015-2023
 #  Leandro Toledo de Souza <devs@python-telegram-bot.org>
 #
 #  This program is free software: you can redistribute it and/or modify
@@ -21,7 +21,6 @@ library.
 """
 import asyncio
 import contextlib
-import logging
 import sys
 from typing import Any, AsyncIterator, Callable, Coroutine, Dict, List, Optional, Union
 
@@ -32,6 +31,7 @@ try:
 except ImportError:
     AIO_LIMITER_AVAILABLE = False
 
+from telegram._utils.logging import get_logger
 from telegram._utils.types import JSONDict
 from telegram.error import RetryAfter
 from telegram.ext._baseratelimiter import BaseRateLimiter
@@ -48,6 +48,9 @@ else:
         yield None
 
 
+_LOGGER = get_logger(__name__, class_name="AIORateLimiter")
+
+
 class AIORateLimiter(BaseRateLimiter[int]):
     """
     Implementation of :class:`~telegram.ext.BaseRateLimiter` using the library
@@ -59,7 +62,7 @@ class AIORateLimiter(BaseRateLimiter[int]):
 
         .. code-block:: bash
 
-           pip install python-telegram-bot[rate-limiter]
+           pip install "python-telegram-bot[rate-limiter]"
 
     The rate limiting is applied by combining two levels of throttling and :meth:`process_request`
     roughly boils down to::
@@ -105,7 +108,7 @@ class AIORateLimiter(BaseRateLimiter[int]):
             to groups and channels per :paramref:`group_time_period`.  When set to 0, no rate
             limiting will be applied. Defaults to 20.
         group_time_period (:obj:`float`): The time period (in seconds) during which the
-            :paramref:`group_time_period` is enforced.  When set to 0, no rate limiting will be
+            :paramref:`group_max_rate` is enforced.  When set to 0, no rate limiting will be
             applied. Defaults to 60.
         max_retries (:obj:`int`): The maximum number of retries to be made in case of a
             :exc:`~telegram.error.RetryAfter` exception.
@@ -118,7 +121,6 @@ class AIORateLimiter(BaseRateLimiter[int]):
         "_group_limiters",
         "_group_max_rate",
         "_group_time_period",
-        "_logger",
         "_max_retries",
         "_retry_after_event",
     )
@@ -134,7 +136,7 @@ class AIORateLimiter(BaseRateLimiter[int]):
         if not AIO_LIMITER_AVAILABLE:
             raise RuntimeError(
                 "To use `AIORateLimiter`, PTB must be installed via `pip install "
-                "python-telegram-bot[rate-limiter]`."
+                '"python-telegram-bot[rate-limiter]"`.'
             )
         if overall_max_rate and overall_time_period:
             self._base_limiter: Optional[AsyncLimiter] = AsyncLimiter(
@@ -144,15 +146,14 @@ class AIORateLimiter(BaseRateLimiter[int]):
             self._base_limiter = None
 
         if group_max_rate and group_time_period:
-            self._group_max_rate = group_max_rate
-            self._group_time_period = group_time_period
+            self._group_max_rate: float = group_max_rate
+            self._group_time_period: float = group_time_period
         else:
             self._group_max_rate = 0
             self._group_time_period = 0
 
         self._group_limiters: Dict[Union[str, int], AsyncLimiter] = {}
-        self._max_retries = max_retries
-        self._logger = logging.getLogger(__name__)
+        self._max_retries: int = max_retries
         self._retry_after_event = asyncio.Event()
         self._retry_after_event.set()
 
@@ -195,15 +196,14 @@ class AIORateLimiter(BaseRateLimiter[int]):
             self._get_group_limiter(group) if group and self._group_max_rate else null_context()
         )
 
-        async with group_context:  # skipcq: PTC-W0062
-            async with base_context:
-                # In case a retry_after was hit, we wait with processing the request
-                await self._retry_after_event.wait()
+        async with group_context, base_context:
+            # In case a retry_after was hit, we wait with processing the request
+            await self._retry_after_event.wait()
 
-                return await callback(*args, **kwargs)
+            return await callback(*args, **kwargs)
 
     # mypy doesn't understand that the last run of the for loop raises an exception
-    async def process_request(  # type: ignore[return]
+    async def process_request(
         self,
         callback: Callable[..., Coroutine[Any, Any, Union[bool, JSONDict, List[JSONDict]]]],
         args: Any,
@@ -232,10 +232,8 @@ class AIORateLimiter(BaseRateLimiter[int]):
             chat = True
 
         # In case user passes integer chat id as string
-        try:
+        with contextlib.suppress(ValueError, TypeError):
             chat_id = int(chat_id)
-        except (ValueError, TypeError):
-            pass
 
         if (isinstance(chat_id, int) and chat_id < 0) or isinstance(chat_id, str):
             # string chat_id only works for channels and supergroups
@@ -249,16 +247,17 @@ class AIORateLimiter(BaseRateLimiter[int]):
                 )
             except RetryAfter as exc:
                 if i == max_retries:
-                    self._logger.exception(
+                    _LOGGER.exception(
                         "Rate limit hit after maximum of %d retries", max_retries, exc_info=exc
                     )
                     raise exc
 
                 sleep = exc.retry_after + 0.1
-                self._logger.info("Rate limit hit. Retrying after %f seconds", sleep)
+                _LOGGER.info("Rate limit hit. Retrying after %f seconds", sleep)
                 # Make sure we don't allow other requests to be processed
                 self._retry_after_event.clear()
                 await asyncio.sleep(sleep)
             finally:
                 # Allow other requests to be processed
                 self._retry_after_event.set()
+        return None  # type: ignore[return-value]
